pub struct ChaCha<const ROUNDS: usize, const IS_IETF: bool> { /* private fields */ }Expand description
ChaCha stream cipher.
IS_IETF selects the nonce/counter layout:
false(DJB original): 64-bit counter at words 12–13, 64-bit nonce at words 14–15.true(IETF / RFC 8439): 32-bit counter at word 12, 96-bit nonce at words 13–15.
Implementations
Sourceimpl<const ROUNDS: usize> ChaCha<ROUNDS, false>
impl<const ROUNDS: usize> ChaCha<ROUNDS, false>
Sourcepub fn new(key: &[u8; 32], nonce: &[u8; 8]) -> ChaCha<ROUNDS, false>
pub fn new(key: &[u8; 32], nonce: &[u8; 8]) -> ChaCha<ROUNDS, false>
Create a new ChaCha instance with the DJB nonce layout (8-byte nonce, 64-bit counter).
Sourcepub fn set_counter(&mut self, counter: u64)
pub fn set_counter(&mut self, counter: u64)
Set the ChaCha counter (words 12 and 13). It can be used to move forward and backward in the keystream.
Sourceimpl<const ROUNDS: usize> ChaCha<ROUNDS, true>
impl<const ROUNDS: usize> ChaCha<ROUNDS, true>
Sourcepub fn new(key: &[u8; 32], nonce: &[u8; 12]) -> ChaCha<ROUNDS, true>
pub fn new(key: &[u8; 32], nonce: &[u8; 12]) -> ChaCha<ROUNDS, true>
Create a new ChaCha instance with the IETF (RFC 8439) nonce layout (12-byte nonce, 32-bit counter).
Sourcepub fn set_counter(&mut self, counter: u32)
pub fn set_counter(&mut self, counter: u32)
Set the ChaCha counter (word 12). The counter is a u32. It can be used to move forward and backward in the keystream.